//=======================================================================
/**
 * @file CustomComboBox.h
 * @author Priyonto M Rahman
 * @copyright Copyright (c) 2023, Priyonto M Rahman
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
//=======================================================================

#ifndef CUSTOMCOMBOBOX_H
#define CUSTOMCOMBOBOX_H

#include <QComboBox>

/**
 * @ingroup TrainingUI
 * @ingroup TestingUI
 * @class CustomComboBox
 * @brief A custom QComboBox with modified popup behavior.
 *
 * This class inherits from QComboBox and provides customization for showing and hiding the popup.
 */
class CustomComboBox : public QComboBox {
    Q_OBJECT

public:
    /**
     * @brief Constructs a CustomComboBox object.
     * @param parent The parent QWidget.
     */
    explicit CustomComboBox(QWidget *parent = nullptr);

protected:
    /**
     * @brief Overrides the QComboBox's showPopup() function to customize the popup behavior.
     */
    void showPopup() override;

    /**
     * @brief Overrides the QComboBox's hidePopup() function to customize the popup behavior.
     */
    void hidePopup() override;
};

#endif // CUSTOMCOMBOBOX_H
