#include "TestFrequencyResponseHelper.h"

#include <QtTest>

void TestFrequencyResponseHelper::testLogspace() {
    std::vector<double> result = FrequencyResponseHelper::logspace(1, 100, 10);

    // Check size
    QCOMPARE(result.size(), 10);

    // Check order
    for (int i = 0; i < result.size() - 1; ++i) {
        QVERIFY(result[i] < result[i + 1]);
    }
}

void TestFrequencyResponseHelper::testCalculateFrequencyResponse() {
    std::vector<double> B = {1.0};
    std::vector<double> A = {1.0};
    double sample_rate = 44100.0;
    std::vector<double> frequencies = {0.5, 1.0, 2.0};

    std::vector<double> result = FrequencyResponseHelper::calculate_frequency_response(B, A, sample_rate, frequencies);

    // Check size
    QCOMPARE(result.size(), frequencies.size());

    // Check gain values. For the current B and A, the system essentially does nothing, so the gain should be 0 dB for all frequencies.
    for (double gain : result) {
        QVERIFY(qFuzzyCompare(gain, 0.0));
    }

    // Test with a different set of coefficients
    B = {2.0, 1.0};
    A = {1.0, 1.0};

    result = FrequencyResponseHelper::calculate_frequency_response(B, A, sample_rate, frequencies);

    // Check size again
    QCOMPARE(result.size(), frequencies.size());

    // Check that none of the gain values are zero since the coefficients have changed
    for (double gain : result) {
        QVERIFY(!qFuzzyCompare(gain, 0.0));
    }

    // Check that the gain values are in decreasing order
    // since a higher frequency should result in lower gain for these coefficients
    for (std::size_t i = 0; i < result.size() - 1; ++i) {
        // TODO: Revisit this.
        QVERIFY(result[i] < result[i + 1]);
    }
}

